@@ -1,3 +1,5 @@
+use std::path::PathBuf;
+
 use thiserror::Error;
 
 #[derive(Error, Debug)]
@@ -8,8 +10,8 @@ pub enum VerifierError {
 	#[error("IO Error")]
 	IoError(#[from] std::io::Error),
 
-	#[error("Bad json")]
-	BadJson,
+	#[error("Bad json: {0}")]
+	ModelHasBadJson(PathBuf),
 
 	#[error("Bad /info endpoint: {0}")]
 	BadInfo(String),
@@ -20,7 +22,7 @@ pub enum VerifierError {
 	#[error("Bad response format (JSON could not be parsed)")]
 	ResponseIsNotJson,
 
-	#[error("Unable to compile the schema (use the --spec option)")]
+	#[error("Unable to compile the schema (use the --model option)")]
 	BadSchema,
 
 	#[error("Bad framework (use the --framework option)")]
@@ -32,9 +34,12 @@ pub enum VerifierError {
 	#[error("Unexpected HTTP status code")]
 	BadStatus,
 
-	#[error("No ids were extracted from the main entity endpoint")]
-	NoIds,
-
+	// TODO: Use errors
+	// #[error("No ids were extracted from the main entity endpoint")]
+	// NoIds,
 	#[error("{0} argument is not a URL")]
 	ArgNotURL(&'static str),
+
+	#[error("Error deserializing JSON: {0}")]
+	SerdeJsonError(#[from] serde_json::Error),
 }
